from datetime import date
from dailydose import hang
from dailydose import fact
from dailydose import news
from dailydose import battleship


def main():
    run = True

    while run:
        today = date.today()
        print(f"{'*' * 20}")
        print(
            f"Today is {today.strftime('%Y-%m-%d')}. Feeling bored? How about...")

        print(f"\t 1. See a fun fact")
        print(f"\t 2. See a news")
        print(f"\t 3. Play hangman")
        print(f"\t 4. Play battleship")
        print(f"\t 5. <Quit>")

        user_selection = input("Choose a number 1-5...\n> ")
        while user_selection not in ["1", "2", "3", "4", "5"]:
            print("Wrong number...")
            user_selection = input("Choose a number 1-5...\n> ")

        if user_selection == "1":
            random_fact = fact.get()
            print(random_fact[0]['heading'])
            print("\n"+random_fact[0]['content'])

        elif user_selection == "2":

            choose = True
            while choose:
                print("Choose from the following subjects... ")
                print("1. Culture")
                print("2. Politics")
                print("3. Science")
                print("4. World")
                print("5. Technology")
                print("6. Environment")
                print("7. Business")
                print("8. <Return to main menu>")

                selection = input(
                    "Enter the number of the subject you want to explore: ")
                if selection not in ['1', '2', '3', '4', '5', '6', '7', '8']:
                    print("Invalid selection. Please try again.")
                    continue
                else:
                    selection = int(selection)
                    choose = False

            if selection != 8:
                if selection == 1:
                    subject = "culture"
                    titular = "CULTURE"
                elif selection == 2:
                    subject = "policy-and-politics"
                    titular = "POLITICS AND POLICY"
                elif selection == 3:
                    subject = "science-and-health"
                    titular = "SCIENCE AND HEALTH"
                elif selection == 4:
                    subject = "world"
                    titular = "WORLD"
                elif selection == 5:
                    subject = "technology"
                    titular = "TECHNOLOGY"
                elif selection == 6:
                    subject = "energy-and-environment"
                    titular = "ENERGY AND ENVIRONMENT"
                elif selection == 7:
                    subject = "business-and-finance"
                    titular = "BUSINESS AND FINANCE"

                news.get_headlines(subject, titular)

            else:
                print("Returning to main menu...")

        elif user_selection == "3":
            number_of_letters = input("Choose the length of word 4-10:\n> ")
            hang.hangman(num_letter=number_of_letters)

        elif user_selection == "4":
            battleship.main()

        else:
            print("Bye!")
            run = False


if __name__ == '__main__':
    main()



# requires pip install 'requests' and 'bs4' 
import requests
from bs4 import BeautifulSoup


def validate_url(subject):
    """
    Compose url and make sure a status code of 200 is returned.
    """
    url = 'https://www.vox.com/' + subject
    response = requests.get(url)
    return response

def get_list(webpage):
    """
    Returns a list of headlines.
    """
    soup = BeautifulSoup(webpage.text, 'html.parser')
    headlines = soup.find('body').find_all('h2', {"class": "c-entry-box--compact__title"})
    today = []
    for x in list(dict.fromkeys(headlines)):
            # exclude single words and questions 
            if len(x.text.split()) > 1 and x.text[-1] != '?':
                today.append(x.text)
    return today

def get_headlines(subject, titular):
    """
    Returns a list of headlines from the BBC News website.
    """
    content = validate_url(subject)

    if content.status_code == 200:
        hd = get_list(content)
        print("\nTODAY'S HEADLINES FROM VOX NEWS ON " + titular + ":\n") 
        for x in hd:
            print(x)

        print("\nRead more at: " + content.url + "\n")
        return True

    else:
        print("Sorry, we had some trouble retrieving the headlines from Vox. Please try again later.")
        return False


if __name__ == "__main__":

    choose = True

    while choose:
        print("Choose from the following subjects... ")
        print("1. Culture")
        print("2. Politics")
        print("3. Science")
        print("4. World")
        print("5. Technology")
        print("6. Environment")
        print("7. Business")
        print("8. <Return to main menu>")

        selection = input("Enter the number of the subject you want to explore: ")
        if selection not in ['1', '2', '3', '4', '5', '6', '7', '8']:
            print("Invalid selection. Please try again.")
            continue
        else:
            selection = int(selection)
            choose = False


    if selection != 8:
        if selection == 1:
            subject = "culture"
            titular = "CULTURE"
        elif selection == 2:
            subject = "policy-and-politics"
            titular = "POLITICS AND POLICY"
        elif selection == 3:
            subject = "science-and-health"
            titular = "SCIENCE AND HEALTH"
        elif selection == 4:
            subject = "world"
            titular = "WORLD"
        elif selection == 5:
            subject = "technology"
            titular = "TECHNOLOGY"
        elif selection == 6:
            subject = "energy-and-environment"
            titular = "ENERGY AND ENVIRONMENT"
        elif selection == 7:
            subject = "business-and-finance"
            titular = "BUSINESS AND FINANCE"
        
        get_headlines(subject, titular)

    else:
        print("Returning to main menu...")







import random
import os
import sys


def get(ship_size, dimension):
    if isinstance(ship_size, int) and isinstance(dimension, int):
        if ship_size < dimension and dimension <= 10 and dimension > 0 and ship_size > 0:
            return ship_size, dimension
        else:
            print("The ship needs to be smaller than the board and maximum dimension size is 10, resorting to default inputs: Ship_size:4, Dimensions:10")
            return 4, 10
    elif isinstance(ship_size, str) and isinstance(dimension, str):
        if ship_size.isnumeric() and dimension.isnumeric():
            ship_size = int(ship_size)
            dimension = int(dimension)
            if ship_size <= dimension and dimension <= 10 and dimension > 0 and ship_size > 0:
                return ship_size, dimension
            else:
                print("The ship needs to be smaller than the board and maximum dimension size is 10, resorting to default inputs: Ship_size:4, Dimensions:10")
                return 4, 10
        else:
            print("Invalid input type, returning default values")
            return 4, 10
    else:
        print("Invalid input type, returning default values")
        return 4, 10


def start_board(dimension):

    # initialising our board with appropriate row and column names and another board to store info
    board = []
    boardx = []
    for i in range(dimension+1):
        board_row = []
        board_rowx = []
        for j in range(dimension+1):
            if j == 0:
                if i == 0:
                    board_row.append(" ")
                    board_rowx.append(" ")
                else:
                    board_row.append(i-1)
                    board_rowx.append(i-1)
            elif i == 0:
                board_row.append(chr(ord('A')+j-1))
                board_rowx.append(chr(ord('A')+j-1))
            else:
                board_row.append(" ")
                board_rowx.append(" ")
        board.append(board_row)
        boardx.append(board_rowx)

    # printing our board for the first time, this is the first thing shown when our program is executed
    # os.system("clear")
    print("\n\n\n" + " "*(dimension+1)+"Welcome to Battleship!\n ")
    for i in range(dimension+1):
        for j in range(dimension+1):
            if i == 0:
                print(str(board[i][j])+"  ", end=" ")
            else:
                print(str(board[i][j])+" |", end=" ")
        print()
        print("  +"+"---+"*dimension)

    return board, boardx


def place_ship(ship_size, dimension, boardx):
    # computer assigns coordinates for the location of our ship using a random function

    x = random.randint(0, 1)
    if x == 1:
        y = random.randint(1, dimension)
        z = random.randint(1, dimension-ship_size+1)
        for i in range(ship_size):
            boardx[y][z+i] = '*'
    else:
        y = random.randint(1, dimension-ship_size+1)
        z = random.randint(1, dimension)
        for i in range(ship_size):
            boardx[y+i][z] = "*"

    return boardx


# loop which asks the users for input, checks user's input and prints board after updating it

def play(board, boardx, ship_size, dimension):
    continue_game = 0
    # for counting the total number of tries taken (only unique attempts and attempts with valid inputs are counted)
    cnt = 0
    strike = 0  # counts the total number of correct strikes on ship
    while (continue_game == 0):
        print("Enter 'exit' to leave game")
        game_input = input(
            "\n  Guess the coordinates of the hidden ship (eg.A6):  ")
        if game_input == "exit":
            print("Goodbye! You played for "+str(cnt)+" turns")
            return 0

        guess = list(game_input)
        if len(guess) == 2 and ord('A')-1 < ord(guess[0]) < ord('A')+dimension and guess[1].isdigit() and 0 <= int(guess[1]) < dimension:
            row_coordinate = int(guess[1])+1
            col_coordinate = ord(guess[0]) - ord('A') + 1
            if board[row_coordinate][col_coordinate] == "X" or board[row_coordinate][col_coordinate] == "#":
                print("  This coordinate has been tried previously. Please try again")
                continue
            if boardx[row_coordinate][col_coordinate] == '*':
                strike = strike+1
                board[row_coordinate][col_coordinate] = 'X'
            else:
                board[row_coordinate][col_coordinate] = '#'
        else:
            print("  Invalid input, please enter the desired coordinate properly")
            continue
        os.system("clear")
        for i in range(dimension+1):
            for j in range(dimension+1):
                if i == 0:
                    print(str(board[i][j])+"  ", end=" ")
                else:
                    print(str(board[i][j])+" |", end=" ")
            print()
            print("  +"+"---+"*dimension)

        cnt = cnt+1
        if strike == ship_size:
            continue_game = 1
            print("\n  Congratulations! You Won!\n""  You took " +
                  str(cnt)+" turns to finish the game.")
            return 1


def main(ship_size="4", dimension="10"):
    if len(sys.argv) >= 3:
        ship_size, dimension = get(sys.argv[1], sys.argv[2])
    else:
        choice = input(
            "No command line input detected. Do you want to select custom ship size, board dimensions? (y/n)")
        if choice == "Y" or choice == "y":
            dimension = input("Input board dimensions (1-10): ")
            ship_size = input(
                "Input ship size (lesser than dimension of board): ")
            ship_size, dimension = get(ship_size, dimension)
        else:
            print("Using default inputs... Ship size=4, Board Dimensions =10*10")
            ship_size, dimension = get(ship_size, dimension)

    board, boardx = start_board(dimension)
    boardx = place_ship(ship_size, dimension, boardx)
    solved = play(board, boardx, ship_size, dimension)



import os
import json
import random


def get(count=1, include_details=True):
    '''
    Returns a fun fact from The Fact Site (thefactsite.com)
    '''

    # Get absolute data path
    data_path = os.path.join(os.path.dirname(
        os.path.abspath(__file__)), "./data/fun_fact.json")

    # Read fun facts data
    fun_facts = json.load(open(data_path, "r", encoding="utf-8"))

    # Sample `count` number of data
    random_fun_facts = random.sample(fun_facts, count)

    # Keep only heading if `include_details=False`
    if not include_details:
        random_fun_facts = [{"heading": fact["heading"]}
                            for fact in random_fun_facts]

    return random_fun_facts


if __name__ == "__main__":
    fact = get()
    print(fact[0]['heading'])
    print("\n"+fact[0]['content'])



from english_words import english_words_lower_alpha_set
import random


def hangman(num_letter):
    if not num_letter.isnumeric():
        print("The function only take positive integers!")
        return "code 1"
    num_letter = int(num_letter)
    if num_letter < 4:
        num_letter = 4
    if num_letter > 10:
        num_letter = 10
    word = ""
    while len(word) != num_letter or not word.isalpha():
        word = random.choice(list(english_words_lower_alpha_set)).lower()
    view = ["\u0332  "] * len(word)
    total_guess = 2*len(word)
    num_guess = total_guess
    correct = 0
    cache = []
    while True:
        num_wrong = total_guess - num_guess
        hang = [" ========="]
        total_height = total_guess - 3 - int((total_guess - 8) / 2)
        rope_length = 1 + int((total_guess - 8) / 2)
        for i in range(0, min(total_height, num_wrong)):
            hang.insert(0, "\t     |")
            num_wrong -= 1
        if num_wrong > 0:
            hang.insert(0, "\t +---+")
            num_wrong -= 1
        index = 1
        for i in range(0, min(rope_length, num_wrong)):
            hang[index] = "\t |   |"
            num_wrong -= 1
            index += 1
        if num_wrong > 0:
            index = 1 + rope_length
            hang[index] = "\t O   |"
            hang[index + 1] = "\t/|\\  |"
            hang[index + 2] = "\t/ \\  |"
        for i in range(len(hang)):
            print(hang[i])
        print("The word is: " + "".join(view))
        if correct == len(word):
            print("Congratulations, the word is " + "".join(word))
            return word
        if num_guess == 0:
            print("The word is " + "".join(word))
            return word
        valid = False
        user_input = ""
        while not valid:
            user_input = input("Guess a letter: ").lower()
            if len(user_input) == 1 and user_input.isalpha():
                if user_input in cache:
                    print("Try another letter!")
                    continue
                valid = True
                cache.append(user_input)
            else:
                print("Input not valid")
        if word.count(user_input) != 0:
            for i in range(len(word)):
                if user_input == word[i].lower():
                    view[i] = "\u0332" + user_input + " "
                    correct += 1
        else:
            num_guess -= 1
        print("\n", end="")